unit jpviewu;

interface

uses
  ShellAPI, 
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  Jpeg, ExtCtrls, StdCtrls, Buttons, FileCtrl, ComCtrls, Spin;

type
  TJpgViewF = class(TForm)
    JpegP: TPanel;
    ControlP: TPanel;
    JpgBox: TScrollBox;
    DirP: TPanel;
    FileListBox: TFileListBox;
    DirectoryListBox: TDirectoryListBox;
    JpgHS: THeaderControl;
    Panel1: TPanel;
    AutoLoCB: TCheckBox;
    FitCB: TCheckBox;
    Panel2: TPanel;
    DriveComboBox: TDriveComboBox;
    Splitter1: TSplitter;
    ExitSB: TSpeedButton;
    SlideBB: TSpeedButton;
    Timer: TTimer;
    PauseSE: TSpinEdit;
    JPGImage1: TImage;
    Label1: TLabel;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure FileListBoxChange(Sender: TObject);
    procedure FileListBoxDblClick(Sender: TObject);
    procedure AutoLoCBClick(Sender: TObject);
    procedure FitCBClick(Sender: TObject);
    procedure JpgBoxResize(Sender: TObject);
    procedure FileListBoxKeyPress(Sender: TObject; var Key: Char);
    procedure FileListBoxKeyDown(Sender: TObject; var Key: Word;
      Shift: TShiftState);
    procedure ExitSBClick(Sender: TObject);
    procedure SlideBBClick(Sender: TObject);
    procedure JPGImage1Progress(Sender: TObject; Stage: TProgressStage;
      PercentDone: Byte; RedrawNow: Boolean; const R: TRect;
      const Msg: String);
    procedure TimerTimer(Sender: TObject);
    procedure Label1Click(Sender: TObject);
  private
    AutoLoad, FitInBox, IsRunning, IsPause : boolean;
    FSlide  : boolean;

    procedure SetSlide( Value : boolean);
    procedure ShowJPG( const FName : string);
    procedure SetJPGBoxBounds;
    property Slide : boolean read FSlide write SetSlide;
    procedure SlideShow;
  public
    { Public declarations }
  end;

var
  JpgViewF: TJpgViewF;

implementation
{$R *.DFM}

function CalcPicSize( PicW, PicH, W, H : integer) : TPoint;
var
  PicAspect : double;
  ByWidth, ByHeight : TPoint;
begin
  if ( W = 0) AND ( H = 0) then begin
    Result.X := PicW;
    Result.Y := PicH;
    exit;
    end;
  PicAspect := PicW / PicH;

  ByWidth.X := W; ByWidth.Y := round( W / PicAspect);
  ByHeight.Y := H; ByHeight.X := round( H * PicAspect);

  if ByWidth.Y <= H then Result := ByWidth
  else                   Result := ByHeight;
end;


procedure TJpgViewF.FormCreate(Sender: TObject);
begin
  AutoLoad := false;
  FitInBox := false;
  FSlide := false;
  IsRunning := false;

  JpegP.Align := alClient;
end;

procedure TJpgViewF.FormDestroy(Sender: TObject);
begin
//  JImage2.Free;
//  JImage.Free;
end;

procedure TJpgViewF.JPGImage1Progress(Sender: TObject;
  Stage: TProgressStage; PercentDone: Byte; RedrawNow: Boolean;
  const R: TRect; const Msg: String);
begin
  JpgHS.Sections.Items[2].Text := IntToStr( PercentDone);
  if Stage = psEnding then IsRunning := false else IsRunning := true;
end;

procedure TJpgViewF.ShowJPG( const FName : string);
begin
  if FName = '' then exit;
  try
    IsRunning := true;
    JPGImage1.Picture.LoadFromFile( FName);
    JPGImage1.Visible := true;
//    while IsRunning do Application.ProcessMessages;
    SetJPGBoxBounds;
    JpgHS.Sections.Items[0].Text :=
      IntToStr( JPGImage1.Picture.Width) + 'x' + IntToStr( JPGImage1.Picture.Height);
  except
    IsRunning := false;
    end;
end;

procedure TJpgViewF.SetJPGBoxBounds;
var
  jH, jW : integer;
  sW, sH, Scale : double;
  PDim : TPoint;
begin
  if NOT Assigned( JPGImage1.Picture.Graphic) then exit;
  jW := JPGImage1.Picture.Width; jH := JPGImage1.Picture.Height;
  if FitInBox then begin
    PDim := CalcPicSize( jW, jH, JpgBox.Width, JpgBox.Height);
    JPGImage1.Stretch := true;
    JPGImage1.Align := alNone;
    JPGImage1.Width  := PDim.X;
    JPGImage1.Height := PDim.Y;
    JPGImage1.Left :=  (JpgBox.Width - PDim.X) DIV 2;
    JPGImage1.Top :=  (JpgBox.Height - PDim.Y) DIV 2;

(*
    if (jW <= JpgBox.Width) AND
       (jH <= JpgBox.Height) then begin { It's fit}
      JPGImage1.Stretch := false;
      JPGImage1.Align := alClient;
      end { It's fit}
    else begin { must resize}
      JPGImage1.Stretch := true;
      JPGImage1.Align := alNone;
{      JPGImage.Left := 0; JPGImage.Top := 0;}
      sW := JpgBox.Width / jW; sH := JpgBox.Height / jH;
      if sW < sH then Scale := sW else Scale := sH;
      JPGImage1.Width := Round( jW * Scale);
      JPGImage1.Height := Round( jH * Scale);
      JPGImage1.Left :=  (JpgBox.Width - JPGImage1.Width) DIV 2;
      JPGImage1.Top :=  (JpgBox.Height - JPGImage1.Height) DIV 2;
      end;{ must resize}
*)      
    end
  else begin
    JPGImage1.Stretch := false;
    JPGImage1.Align := alClient;
    JpgBox.VertScrollBar.Range := jW;
    JpgBox.HorzScrollBar.Range := jH;
    end;
  if JPGImage1.Stretch then JpgHS.Sections.Items[1].Text := 'Stretch'
  else                      JpgHS.Sections.Items[1].Text := 'Actual';
end;

procedure TJpgViewF.FileListBoxChange(Sender: TObject);
begin
  if ( NOT AutoLoad) OR Slide then exit;
  try ShowJpg( FileListBox.FileName)
  except end;
end;

procedure TJpgViewF.FileListBoxDblClick(Sender: TObject);
begin
  try ShowJPG( FileListBox.FileName);
  except end;
end;

procedure TJpgViewF.AutoLoCBClick(Sender: TObject);
begin
  AutoLoad := AutoLoCB.Checked;
end;

procedure TJpgViewF.FitCBClick(Sender: TObject);
begin
  FitInBox := FitCB.Checked;
  JpgBox.VertScrollBar.Visible := NOT FitInBox;
  JpgBox.HorzScrollBar.Visible := NOT FitInBox;
  SetJPGBoxBounds;
end;

procedure TJpgViewF.JpgBoxResize(Sender: TObject);
begin
  SetJPGBoxBounds;
end;

procedure TJpgViewF.FileListBoxKeyPress(Sender: TObject; var Key: Char);
begin
  case Key of
    ' ', #13 : begin
      try ShowJpg( FileListBox.FileName)
      except end;
      end;

    end;
end;

procedure TJpgViewF.FileListBoxKeyDown(Sender: TObject; var Key: Word;
  Shift: TShiftState);
var ItNum : integer;
begin
  if Key = 46 then begin { delete}
    DeleteFile( FileListBox.FileName);
    ItNum := FileListBox.ItemIndex;
    FileListBox.Items.Delete( ItNum);
    if ItNum > FileListBox.Items.Count - 1 then
      ItNum := FileListBox.Items.Count - 1;
    FileListBox.ItemIndex := ItNum;
    FileListBoxChange( FileListBox);
    end;
end;

procedure TJpgViewF.SlideShow;
begin
  Timer.Interval := PauseSE.Value * 1000;
  while ( FileListBox.ItemIndex < FileListBox.Items.Count) AND Slide do begin
    try ShowJpg( FileListBox.FileName)
    except end;
    IsPause := true;
    while IsPause do Application.ProcessMessages;
    FileListBox.ItemIndex := FileListBox.ItemIndex + 1;
    end;
end;

procedure TJpgViewF.ExitSBClick(Sender: TObject);
begin Close; end;

procedure TJpgViewF.SetSlide( Value : boolean);
begin
  if FSlide = Value then exit;
  FSlide := Value;
  if FSlide then SlideShow;
end;

procedure TJpgViewF.SlideBBClick(Sender: TObject);
begin
  Slide := SlideBB.Down;
end;

procedure TJpgViewF.TimerTimer(Sender: TObject);
begin
  IsPause := false;
end;







procedure TJpgViewF.Label1Click(Sender: TObject);
var TempString : array[0..79] of char;
begin
   StrPCopy( TempString, 'http://www.kochini.com');
   ShellExecute(0, Nil, TempString, Nil, Nil, SW_NORMAL);
end;

end.
